# Welcome to Azure MLOPs Helper Documentation.

## Introduction

This library is intended to ease the various steps needed to enable the storage, training, and deployment of a model with Azure Machine Learning.

This is highly inspired from the series of posts found in the [following blog](https://benalexkeen.com/creating-end-to-end-mlops-pipelines-using-azure-ml-and-azure-pipelines-part-1/).

This is mostly a wrapper around azure-ml python classes and some glue code.

!!! info "Remark"

    **If you know what you are doing with AzureML, you'll probably don't need this library.**

## Resources

* [Open source cheat sheets for Azure ML](https://azure.github.io/azureml-cheatsheets/)
